// Copyright © 2010 DELAYEN Julien, DELAYEN Florent

/*
    This file is part of Schedio.

    Schedio is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Schedio is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Schedio.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <stdlib.h>
#include <sys/stat.h>
#include "schedio.h"
#include <gtk/gtk.h>
#include <getopt.h>

void print_usage (FILE* stream, int exit_code)
{
  fprintf (stream, "Usage: %s options [ inputfile ... ]\n", "schedio");
  fprintf (stream,
           " -h --help      Display this usage information.\n"
	   " -l --lock      Launch a locked schedio\n"
       " -m --mask      Launch schedio in masked mode.\n"
	   );

  exit (exit_code);
}


int main (int argc, char *argv[])
{
    FILE *f = NULL;
    char *dir = NULL;
    struct stat st;
    mode_t permission = 01777;

    /* Initialize GTK+ */
    int next_option;
    const char* const short_options = "hm";
    const struct option long_options[]={
    {"help",0,NULL,'h'},
    {"mask",0,NULL,'m'},
    {NULL,0,NULL,0}
    };

    schedio_visible = 1;

    do {
      next_option = getopt_long (argc, argv, short_options,
                                  long_options, NULL);
      switch (next_option)
      {
      case 'h':    /* -h or --help */
         /* User has requested usage information. Print it to standard
            output, and exit with exit code zero (normal termination). */
         print_usage (stdout, 0);
         break;

      case 'm':
         schedio_visible = 0;
         break;

      case '?':    /* The user specified an invalid option. */
         /* Print usage information to standard error, and exit with exit
            code one (indicating abnormal termination). */
         print_usage (stderr, 1);
         break;

      case -1:     /* Done with options.  */
         break;

      default:     /* Something else: unexpected.  */
         abort ();
      }
    }
    while (next_option != -1);

    g_log_set_handler ("Gtk", G_LOG_LEVEL_WARNING, (GLogFunc) gtk_false, NULL);
    gtk_init (&argc, &argv);
    g_log_set_handler ("Gtk", G_LOG_LEVEL_WARNING, g_log_default_handler, NULL);

    pwd = getenv ("HOME");

    dir = malloc(strlen(pwd)+sizeof("/.schedio"));
    strcpy(dir,pwd);
    strcat(dir,"/.schedio");

    if(stat(dir,&st) != 0)mkdir(dir,permission);

    free(dir);

    dir = malloc(strlen(pwd)+sizeof("/.schedio/plugin"));
    strcpy(dir,pwd);
    strcat(dir,"/.schedio/plugin");

    if(stat(dir,&st) != 0)mkdir(dir,permission);

    free(dir);

    dir = malloc(strlen(pwd)+sizeof("/.schedio/plugin_ncy"));
    strcpy(dir,pwd);
    strcat(dir,"/.schedio/plugin_ncy");

    if(stat(dir,&st) != 0)mkdir(dir,permission);

    free(dir);

    dir = malloc(strlen(pwd)+sizeof("/.schedio/startup"));
    strcpy(dir,pwd);
    strcat(dir,"/.schedio/startup");

    if(stat(dir,&st) != 0)mkdir(dir,permission);

    free(dir);

    dir = malloc(strlen(pwd)+sizeof("rm -r /.schedio/visual"));
    strcpy(dir,"rm -r ");
    strcat(dir,pwd);
    strcat(dir,"/.schedio/visual");
    system(dir);

    free(dir);

    dir = malloc(strlen(pwd)+sizeof("/.schedio/visual"));
    strcpy(dir,pwd);
    strcat(dir,"/.schedio/visual");

    if(stat(dir,&st) != 0)mkdir(dir,permission);

    free(dir);

    dir = malloc(strlen(pwd)+sizeof("rm -r /.schedio/tmp"));
    strcpy(dir,"rm -r ");
    strcat(dir,pwd);
    strcat(dir,"/.schedio/tmp");
    system(dir);

    free(dir);

    dir = malloc(strlen(pwd)+sizeof("/.schedio/tmp"));
    strcpy(dir,pwd);
    strcat(dir,"/.schedio/tmp");

    if(stat(dir,&st) != 0)mkdir(dir,permission);

    free(dir);

    dir = malloc(strlen(pwd)+sizeof("/.schedio/startup/startup.conf"));
    strcpy(dir,pwd);
    strcat(dir,"/.schedio/startup/startup.conf");

    f = fopen(dir,"a+");
    fclose(f);

    free(dir);

    dir = malloc(strlen(pwd)+sizeof("/.schedio/liststore.tmp"));
    strcpy(dir,pwd);
    strcat(dir,"/.schedio/liststore.tmp");
    f = fopen(dir,"w+");
    fclose(f);

    free(dir);

    dir = malloc(strlen(pwd)+sizeof("/.schedio/liststore.tmp1"));
    strcpy(dir,pwd);
    strcat(dir,"/.schedio/liststore.tmp1");
    f = fopen(dir,"w+");
    fclose(f);

    free(dir);

    Schedio_init();

    gtk_main ();
    return 0;
}
